const {sqlHandle} = require("../config/db")
const {isValue, paramToUnder} = require("../../util/index")
const PageResult = require("../config/page")
const HoverService = {
  getUserInfo: () => {
    return new Promise(async (resolve, reject) => {
      try {
        const userInfo = {
          username: 'admin',
          timestamp: new Date().getTime(),
          isAdmin: true
        }
        setTimeout(() => {
          return resolve(userInfo)
        }, 1000)
      } catch (e) {
        return reject(e.sqlMessage)
      }
    })
  },
  mockGetConfig: () => {
    return new Promise(async (resolve, reject) => {
      try {
        const result = {
          // mainColor: 'rgba(46, 129, 255, 1)',
          mainColor: 'rgba(255,46,84, 1)',
          textColor1: 'rgba(48,49,51,1)',
          textColor2: 'rgba(96,98,102,1)',
          textColor3: 'rgba(144,147,153,1)',
          textColor4: 'rgba(192,196,204,1)',
        }
        setTimeout(() => {
          return resolve(result)
        }, 1000)
      } catch (e) {
        return reject(e.sqlMessage)
      }
    })
  },
  getSearchArea: () => {
    return new Promise(async (resolve, reject) => {
      try {
        const result = [
          {
            name: '对象标签',
            children: [
              {indexName: '人员', indexKey: 'index_dx_ry', children: [
                  {indexName: '人员档案信息', indexKey: 'index_dx_ry-1'},
                  {indexName: '户籍人口信息', indexKey: 'index_dx_ry-2'},
                  {indexName: '人口基本信息', indexKey: 'index_dx_ry-3'},
                ]
              },
              {indexName: '物品', indexKey: 'index_dx_wp', children: [
                  {indexName: '车辆基础信息', indexKey: 'index_dx_wp-1'},
                  {indexName: '出港车辆信息', indexKey: 'index_dx_wp—2'},
                  {indexName: '出租汽车基础信息', indexKey: 'index_dx_wp-3'},
                ]
              },
              {indexName: '地址', indexKey: 'index_dx_dz', children: [
                  {indexName: '摄像头点位信息', indexKey: 'index_dx_dz-1'},
                  {indexName: '房屋出租信息', indexKey: 'index_dx_dz—2'},
                  {indexName: '隧道信息', indexKey: 'index_dx_dz-3'},
                ]
              },
              {indexName: '组织', indexKey: 'index_dx_zz', children: [
                  {indexName: '政法机构信息', indexKey: 'index_dx_zz-1'},
                  {indexName: '安全生产监管企业违规记录信息', indexKey: 'index_dx_zz—2'},
                ]
              },
              {indexName: '公共', indexKey: 'index_dx_gg', children: [
                  {indexName: '全省景区信息', indexKey: 'index_dx_gg-1'},
                  {indexName: '环岛码头信息', indexKey: 'index_dx_gg—2'},
                ]
              },
              {indexName: '其他', indexKey: 'index_dx_qt', children: [
                  {indexName: 'XXXXXXXXX子项1', indexKey: 'index_dx_qt-1'},
                  {indexName: 'XXXXXXXXX子项2', indexKey: 'index_dx_qt—2'},
                  {indexName: 'XXXXXXXXX子项3', indexKey: 'index_dx_qt—3'},
                  {indexName: 'XXXXXXXXX子项4', indexKey: 'index_dx_qt—4'},
                  {indexName: 'XXXXXXXXX子项5', indexKey: 'index_dx_qt—5'},
                  {indexName: 'XXXXXXXXX子项6', indexKey: 'index_dx_qt—6'},
                  {indexName: 'XXXXXXXXX子项7', indexKey: 'index_dx_qt—7'},
                  {indexName: 'XXXXXXXXX子项8', indexKey: 'index_dx_qt—8'},
                  {indexName: 'XXXXXXXXX子项9', indexKey: 'index_dx_qt—9'},
                  {indexName: 'XXXXXXXXX子项10', indexKey: 'index_dx_qt—10'},
                  {indexName: 'XXXXXXXXX子项11', indexKey: 'index_dx_qt—11'},
                  {indexName: 'XXXXXXXXX子项12', indexKey: 'index_dx_qt—12'},
                ]
              },
            ]
          },
          {
            name: '主题标签',
            children: [
              {indexName: '人口库', indexKey: 'index_zt_rkk', children: [
                  {indexName: '常住人口信息', indexKey: 'index_zt_rkk-1'},
                  {indexName: '流动人口信息', indexKey: 'index_zt_rkk—2'},
                  {indexName: '境外人员基本信息', indexKey: 'index_zt_rkk—3'},
                ]
              },
              {indexName: '法人库', indexKey: 'index_zt_frk', children: [
                  {indexName: '企业法人基本信息', indexKey: 'index_zt_frk-1'},
                  {indexName: '企业法人行政处罚记录', indexKey: 'index_zt_frk—2'},
                  {indexName: '企业基本信息', indexKey: 'index_zt_frk—3'},
                ]
              },
              {indexName: '警情案事件', indexKey: 'index_zt_jqasj', children: [
                  {indexName: '案件基本信息', indexKey: 'index_zt_jqasj-1'},
                ]
              },
              {indexName: '重点关注对象', indexKey: 'index_zt_zdgzdx', children: [
                  {indexName: '涉毒前科人员基本信息', indexKey: 'index_zt_zdgzdx-1'},
                ]
              },
              {indexName: '关注群体', indexKey: 'index_zt_gzqt', children: [
                  {indexName: '社区矫正人员', indexKey: 'index_zt_gzqt-1'},
                ]
              },
              {indexName: '车辆库', indexKey: 'index_zt_clk', children: [
                  {indexName: '家用汽车基本信息', indexKey: 'index_zt_clk-1'},
                ]
              },
              {indexName: '船舶库', indexKey: 'index_zt_cbk', children: [
                  {indexName: '三无船舶信息', indexKey: 'index_zt_cbk-1'},
                ]
              },
              {indexName: '非机动车库', indexKey: 'index_zt_fjdck', children: [
                  {indexName: '电瓶车证件信息', indexKey: 'index_zt_fjdck-1'},
                ]
              },
            ]
          },
          {
            name: '专题标签',
            children: [
              {indexName: '人际关系', indexKey: 'index_zhuant_rjgx', children: [
                  {indexName: '同届校生关系', indexKey: 'index_zhuant_rjgx-1'},
                  {indexName: '同期社保记录', indexKey: 'index_zhuant_rjgx—2'},
                  {indexName: '同期公积金记录', indexKey: 'index_zhuant_rjgx—3'},
                ]
              },
              {indexName: '离岛免税', indexKey: 'index_zhuant_ldms', children: [
                  {indexName: '同行车辆人员', indexKey: 'index_zhuant_ldms-1'},
                  {indexName: '同行船舶人员', indexKey: 'index_zhuant_ldms—2'},
                  {indexName: '频繁往返进出岛人员', indexKey: 'index_zhuant_ldms—3'},
                ]
              },
            ]
          },
        ]
        return resolve(result)
      } catch (e) {
        return reject(e.sqlMessage)
      }
    })
  },
  getSearchHistory: () => {
    return new Promise(async (resolve, reject) => {
      try {
        const result = [
          '胡杰',
          '临1234567',
          '123012301204012591295192',
          '爱神的箭阿三代售点加上基地啊家是',
          'asfasfasfasf',
          'asfasfas',
          'gas啊军嫂上岛萨克管阿莎',
          'asdasdas',
          '1',
          '2',
          '这是一个国家城市省份的地址',
          '海南省 海口市 龙华区 海垦街道 海南省公安厅 胡杰 琼 宝马'
        ]
        setTimeout(() => {
          return resolve(result)
        }, 1000)
      } catch (e) {
        return reject(e.sqlMessage)
      }
    })
  },
}
module.exports = HoverService